IF OBJECT_ID('[DockerImages_Extended]') IS NOT NULL DROP VIEW [DockerImages_Extended]
GO

CREATE VIEW [DockerImages_Extended]
AS

SELECT DR.[Feed_Id],
       DR.[Repository_Name],
       DI.*,
       [ContainerConfigBlob_Digest] = DB.[Blob_Digest],
	   VULN.[Vulnerabilities_Severity_Code],
	   VULN.[Vulnerabilities_Unassessed_Indicator],
	   [Vulnerabilities_Count] = COALESCE(VULN.[Vulnerabilities_Count],0)
  FROM [DockerImages] DI
       INNER JOIN [DockerRepositories] DR
               ON DR.[DockerRepository_Id] = DI.[DockerRepository_Id]
        LEFT JOIN [DockerBlobs] DB
               ON DB.[DockerBlob_Id] = DI.[ContainerConfigBlob_Id]
        LEFT JOIN (SELECT DIL.[DockerImage_Id], 
	                     [Vulnerabilities_Severity_Code] = SUBSTRING('EWCN', MAX(CHARINDEX(A.[Severity_Code],'EWCN')), 1),
						 [Vulnerabilities_Unassessed_Indicator] = CASE WHEN COUNT(CASE WHEN A.[Severity_Code] IS NULL THEN 1 ELSE NULL END) = 0 THEN 'N' ELSE 'Y' END,
	                     [Vulnerabilities_Count] = COUNT(*)
                    FROM [Vulnerabilities] V
                         LEFT JOIN [AssessmentTypes] A
                                ON A.[AssessmentType_Id] = V.[AssessmentType_Id]
                              AND (A.[Expiration_Days] IS NULL OR DATEADD(day, A.[Expiration_Days], V.[Assessment_Date]) > GETUTCDATE())
                       INNER JOIN [FeedVulnerabilitySources] FVS ON FVS.[VulnerabilitySource_Id] = V.[VulnerabilitySource_Id]
                       INNER JOIN [DockerBlobs] DB ON DB.[Blob_Digest] = V.[Blob_Digest]
                       INNER JOIN [DockerImageLayers] DIL ON DIL.[DockerBlob_Id] = DB.[DockerBlob_Id]
                  GROUP BY DIL.[DockerImage_Id]) VULN
               ON VULN.[DockerImage_Id] = DI.[DockerImage_Id]
GO
