EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'DockerBlobs_CreateOrUpdateBlob',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates or modifies a blob.'
GO

IF OBJECT_ID('[DockerBlobs_CreateOrUpdateBlob]') IS NOT NULL DROP PROCEDURE [DockerBlobs_CreateOrUpdateBlob]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [DockerBlobs_CreateOrUpdateBlob]
(
	@Feed_Id INT,
	@Blob_Digest VARCHAR(128),
	@Blob_Size BIGINT,
	@MediaType_Name VARCHAR(255) = NULL,
	@Cached_Indicator YNINDICATOR = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF NOT EXISTS(SELECT * FROM [DockerBlobs] WITH (UPDLOCK) WHERE ([Feed_Id] = @Feed_Id OR ([Feed_Id] IS NULL AND @Feed_Id IS NULL)) AND [Blob_Digest] = @Blob_Digest)
	BEGIN
		
		INSERT INTO [DockerBlobs]
		(
			[Feed_Id],
			[Blob_Digest],
			[Download_Count],
			[Blob_Size],
			[MediaType_Name],
			[Cached_Indicator]
		)
		VALUES
		(
			@Feed_Id,
			@Blob_Digest,
			0,
			@Blob_Size,
			@MediaType_Name,
			COALESCE(@Cached_Indicator, 'N')
		)

	END
	ELSE
	BEGIN

		UPDATE [DockerBlobs]
		   SET [Blob_Size] = @Blob_Size,
		       [MediaType_Name] = COALESCE(@MediaType_Name, [MediaType_Name]),
		       [Cached_Indicator] = COALESCE(@Cached_Indicator, [Cached_Indicator])
		 WHERE ([Feed_Id] = @Feed_Id OR ([Feed_Id] IS NULL AND @Feed_Id IS NULL)) 
		   AND [Blob_Digest] = @Blob_Digest

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DockerBlobs_CreateOrUpdateBlob] TO [ProGetUser_Role]
GO