EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'DockerImages_CreateImage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'DockerImage_Id',
    /* Description_Text        */ 'Creates an image.'
GO

IF OBJECT_ID('[DockerImages_CreateImage]') IS NOT NULL DROP PROCEDURE [DockerImages_CreateImage]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [DockerImages_CreateImage]
(
	@Feed_Id INT,
	@Repository_Name VARCHAR(255),
	@Tag_Name VARCHAR(128),
	@Image_Digest VARCHAR(128),
	@ManifestJson_Bytes VARBINARY(MAX),
	@Cached_Indicator YNINDICATOR,
	@ContainerConfigBlob_Id INT,
	@DockerImage_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @DockerRepository_Id INT
	SET @DockerRepository_Id = (SELECT [DockerRepository_Id]
	                              FROM [DockerRepositories]
								 WHERE [Feed_Id] = @Feed_Id
								   AND [Repository_Name] = @Repository_Name)

	IF @DockerRepository_Id IS NULL
	BEGIN

		INSERT INTO [DockerRepositories]
		(
			[Feed_Id],
			[Repository_Name]
		)
		VALUES
		(
			@Feed_Id,
			@Repository_Name
		)

		SET @DockerRepository_Id = SCOPE_IDENTITY()

	END

	SET @DockerImage_Id = (SELECT [DockerImage_Id]
	                         FROM [DockerImages]
							WHERE [DockerRepository_Id] = @DockerRepository_Id
							  AND [Image_Digest] = @Image_Digest)

	IF @DockerImage_Id IS NULL
	BEGIN
		INSERT INTO [DockerImages]
		(
			[DockerRepository_Id],
			[Image_Digest],
			[ManifestJson_Bytes],
			[Download_Count],
			[Cached_Indicator],
			[Published_Date],
			[ContainerConfigBlob_Id]
		)
		VALUES
		(
			@DockerRepository_Id,
			@Image_Digest,
			@ManifestJson_Bytes,
			0,
			COALESCE(@Cached_Indicator, 'N'),
			GETUTCDATE(),
			@ContainerConfigBlob_Id
		)

		SET @DockerImage_Id = SCOPE_IDENTITY()

		EXEC [Events_RaiseEvent] 'PKGADD', @Feed_Id, 'Package_Name', @Repository_Name, 'Package_Version', @Image_Digest
	END

	IF @Tag_Name IS NOT NULL
	BEGIN

		IF EXISTS(SELECT * FROM [DockerRepositoryTags] WITH (UPDLOCK) WHERE [DockerRepository_Id] = @DockerRepository_Id AND [Tag_Name] = @Tag_Name)
		BEGIN
			UPDATE [DockerRepositoryTags]
			   SET [DockerImage_Id] = @DockerImage_Id
			 WHERE [DockerRepository_Id] = @DockerImage_Id
			   AND [Tag_Name] = @Tag_Name

			EXEC [Events_RaiseEvent] 'PKGMDF', @Feed_Id, 'Package_Name', @Repository_Name, 'Package_Version', @Tag_Name
		END
		ELSE
		BEGIN
			INSERT INTO [DockerRepositoryTags]
			(
				[DockerRepository_Id],
				[Tag_Name],
				[DockerImage_Id]
			)
			VALUES
			(
				@DockerRepository_Id,
				@Tag_Name,
				@DockerImage_Id
			)

			EXEC [Events_RaiseEvent] 'PKGADD', @Feed_Id, 'Package_Name', @Repository_Name, 'Package_Version', @Tag_Name
		END

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DockerImages_CreateImage] TO [ProGetUser_Role]
GO