EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'DockerImages_CreateOrUpdateRepository',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'DockerRepository_Id',
    /* Description_Text        */ 'Creates or updates a Docker repository.'
GO

IF OBJECT_ID('[DockerImages_CreateOrUpdateRepository]') IS NOT NULL DROP PROCEDURE [DockerImages_CreateOrUpdateRepository]
IF OBJECT_ID('[DockerImages_UpdateDescription]') IS NOT NULL DROP PROCEDURE [DockerImages_UpdateDescription]

GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [DockerImages_CreateOrUpdateRepository]
(
	@Feed_Id INT,
	@Repository_Name VARCHAR(255),
	@RepositoryIcon_Url VARCHAR(1000),
	@ShortDescription_Text NVARCHAR(100),
	@FullDescription_Text NVARCHAR(MAX),
	@DockerRepository_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @DockerRepository_Id IS NULL
	BEGIN

		INSERT INTO [DockerRepositories]
		(
			[Feed_Id],
			[Repository_Name],
			[RepositoryIcon_Url],
			[ShortDescription_Text],
			[FullDescription_Text]
		)
		VALUES
		(
			@Feed_Id,
			@Repository_Name,
			@RepositoryIcon_Url,
			@ShortDescription_Text,
			@FullDescription_Text
		)

		SET @DockerRepository_Id = SCOPE_IDENTITY()

	END
	ELSE

		UPDATE [DockerRepositories]
		   SET [ShortDescription_Text] = @ShortDescription_Text,
		       [FullDescription_Text] = @FullDescription_Text,
			   [RepositoryIcon_Url] = @RepositoryIcon_Url
		 WHERE [DockerRepository_Id] = @DockerRepository_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DockerImages_CreateOrUpdateRepository] TO [ProGetUser_Role]
GO