EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'PackageDependents_CreateOrUpdatePackageDependent',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'PackageDependent_Id',
    /* Description_Text        */ 'Creates a package dependent.'
GO

IF OBJECT_ID('[PackageDependents_CreateOrUpdatePackageDependent]') IS NOT NULL DROP PROCEDURE [PackageDependents_CreateOrUpdatePackageDependent]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [PackageDependents_CreateOrUpdatePackageDependent]
(
	@Feed_Id INT,
	@Package_Name VARCHAR(200),
	@Group_Name VARCHAR(200),
	@Version_Text VARCHAR(100),
	@Dependent_Feed_Id INT,
	@Dependent_Package_Name VARCHAR(200),
	@Dependent_Group_Name VARCHAR(200),
	@Dependent_Version_Text VARCHAR(100),
	@Dependent_Url VARCHAR(1000),
	@Notes_Text NVARCHAR(MAX),
	@PackageDependent_Id INT = NULL OUT
)
AS
BEGIN

	SET NOCOUNT ON

	SELECT @@ROWCOUNT

	IF @PackageDependent_Id IS NULL 
	BEGIN

		SET @Group_Name = NULLIF(@Group_Name, '')
		SET @Dependent_Group_Name = NULLIF(@Dependent_Group_Name, '')
		SET @Notes_Text = NULLIF(@Notes_Text, '')

		SET @PackageDependent_Id = (SELECT [PackageDependent_Id]
									  FROM [PackageDependents]
									 WHERE [Feed_Id] = @Feed_Id
									   AND [Package_Name] = @Package_Name
									   AND ([Group_Name] = @Group_Name OR ([Group_Name] IS NULL AND @Group_Name IS NULL))
									   AND [Version_Text] = @Version_Text
									   AND [Dependent_Package_Name] = @Dependent_Package_Name
									   AND ([Dependent_Group_Name] = @Dependent_Group_Name OR ([Dependent_Group_Name] IS NULL AND @Dependent_Group_Name IS NULL))
									   AND [Dependent_Version_Text] = @Dependent_Version_Text)
	END

	IF @PackageDependent_Id IS NOT NULL
	BEGIN
		UPDATE [PackageDependents]
			SET [Dependent_Feed_Id] = @Dependent_Feed_Id,
			    [Dependent_Url] = @Dependent_Url,
				[Notes_Text] = @Notes_Text
			WHERE [PackageDependent_Id] = @PackageDependent_Id
	END ELSE BEGIN
		INSERT INTO [PackageDependents]
		(
			[Feed_Id],
			[Package_Name],
			[Group_Name],
			[Version_Text],
			[Dependent_Feed_Id],
			[Dependent_Url],
			[Dependent_Package_Name],
			[Dependent_Group_Name],
			[Dependent_Version_Text],
			[Notes_Text]
		)
		VALUES
		(
			@Feed_Id,
			@Package_Name,
			@Group_Name,
			@Version_Text,
			@Dependent_Feed_Id,
			@Dependent_Url,
			@Dependent_Package_Name,
			@Dependent_Group_Name,
			@Dependent_Version_Text,
			@Notes_Text
		)

		SET @PackageDependent_Id = SCOPE_IDENTITY()
	END
END
GO

GRANT EXECUTE ON [PackageDependents_CreateOrUpdatePackageDependent] TO [ProGetUser_Role]
GO
