EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'PackageUsage_RecordPackages',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Records the specified package data.'
GO

IF OBJECT_ID('[PackageUsage_RecordPackages]') IS NOT NULL DROP PROCEDURE [PackageUsage_RecordPackages]
GO

SET QUOTED_IDENTIFIER ON
GO

IF TYPE_ID('PackageUsageEntry') IS NOT NULL DROP TYPE PackageUsageEntry

CREATE TYPE PackageUsageEntry AS TABLE
(
	[Server_Name] NVARCHAR(100) NOT NULL,
	[PackageType_Name] VARCHAR(20) NOT NULL,
	[Package_Name] VARCHAR(200) NOT NULL,
	[Package_Version] VARCHAR(200) NULL,
	[Details_Url] VARCHAR(256) NULL,
	[Installed_Date] DATETIME NULL
)
GO

GRANT EXECUTE ON TYPE::[PackageUsageEntry] TO [ProGetUser_Role]
GO

CREATE PROCEDURE [PackageUsage_RecordPackages]
(
	@PackageContainerScanner_Id INT,
	@PackageUsageEntry_Table dbo.PackageUsageEntry READONLY
)
AS
BEGIN

	SET NOCOUNT ON

BEGIN TRY
    BEGIN TRANSACTION

	-- use CTE as filter to prevent full table scan
	;WITH Filtered_PU
	AS
	(
		SELECT *
		  FROM [PackageUsage]
		 WHERE [PackageContainerScanner_Id] = @PackageContainerScanner_Id
	)
	MERGE Filtered_PU AS TARGET
	USING @PackageUsageEntry_Table AS SOURCE
	   ON (
	           TARGET.[PackageType_Name] = SOURCE.[PackageType_Name]
	       AND TARGET.[Package_Name] = SOURCE.[Package_Name]
		   AND TARGET.[Package_Version] = SOURCE.[Package_Version]
		   AND TARGET.[Server_Name] = SOURCE.[Server_Name]
		  )

	 WHEN MATCHED THEN
		UPDATE SET TARGET.[Details_Url] = SOURCE.[Details_Url],
		           TARGET.[PackageStatus_Code] = 'I',
				   TARGET.[Updated_Date] = GETUTCDATE(),
				   TARGET.[Installed_Date] = COALESCE(SOURCE.[Installed_Date], TARGET.[Installed_Date], GETUTCDATE()),
				   TARGET.[Removed_Date] = NULL

	 WHEN NOT MATCHED BY TARGET THEN
		INSERT
		(
			[PackageContainerScanner_Id],
			[Server_Name],
			[PackageType_Name],
			[Package_Name],
			[Package_Version],
			[Details_Url],
			[PackageStatus_Code],
			[Updated_Date],
			[Installed_Date]
		)
		VALUES
		(
			@PackageContainerScanner_Id,
			SOURCE.[Server_Name],
			SOURCE.[PackageType_Name],
			SOURCE.[Package_Name],
			SOURCE.[Package_Version],
			SOURCE.[Details_Url],
			'I',
			GETUTCDATE(),
			COALESCE(SOURCE.[Installed_Date], GETUTCDATE())
		)

	 WHEN NOT MATCHED BY SOURCE THEN
		UPDATE SET TARGET.[PackageStatus_Code] = 'R',
		           TARGET.[Removed_Date] = COALESCE(TARGET.[Removed_Date], GETUTCDATE()),
				   TARGET.[Updated_Date] = GETUTCDATE()
	;

    COMMIT
END TRY BEGIN CATCH
    IF XACT_STATE()<>0 ROLLBACK
    EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [PackageUsage_RecordPackages] TO [ProGetUser_Role]
GO