EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Vulnerabilities_CreateOrUpdateVulnerability',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Vulnerability_Id',
    /* Description_Text        */ 'Creates a new known vulnerability or updates an existing one.'
GO

IF OBJECT_ID('[Vulnerabilities_CreateOrUpdateVulnerability]') IS NOT NULL DROP PROCEDURE [Vulnerabilities_CreateOrUpdateVulnerability]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Vulnerabilities_CreateOrUpdateVulnerability]
(
	@FeedType_Name VARCHAR(20),
	@External_Id VARCHAR(20),
	@Package_Name VARCHAR(200),
	@Package_Versions VARCHAR(1000),
	@Blob_Digest VARCHAR(128),
	@Title_Text NVARCHAR(200),
	@Description_Text NVARCHAR(MAX),
	@VulnerabilitySource_Id INT,
	@Vulnerability_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Vulnerability_Id IS NULL
	BEGIN

		INSERT INTO [Vulnerabilities]
		(
			[FeedType_Name],
			[External_Id],
			[Package_Name],
			[Package_Versions],
			[Title_Text],
			[Description_Text],
			[VulnerabilitySource_Id],
			[Blob_Digest]
		)
		VALUES
		(
			@FeedType_Name,
			@External_Id,
			@Package_Name,
			@Package_Versions,
			@Title_Text,
			@Description_Text,
			@VulnerabilitySource_Id,
			@Blob_Digest
		)

		SET @Vulnerability_Id = SCOPE_IDENTITY()

	END
	ELSE
	BEGIN

		UPDATE [Vulnerabilities]
		   SET [FeedType_Name] = @FeedType_Name,
		       [External_Id] = @External_Id,
			   [Package_Name] = @Package_Name,
			   [Package_Versions] = @Package_Versions,
			   [Title_Text] = @Title_Text,
			   [Description_Text] = @Description_Text,
			   [VulnerabilitySource_Id] = @VulnerabilitySource_Id,
			   [Blob_Digest] = @Blob_Digest
		 WHERE [Vulnerability_Id] = @Vulnerability_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Vulnerabilities_CreateOrUpdateVulnerability] TO [ProGetUser_Role]
GO